==> haskell-hsyslog-5.0.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyslog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hsyslog
version:              5.0.2
visibility:           public
id:                   hsyslog-5.0.2-HrqZFRpCUr5kkKpBas09N
key:                  hsyslog-5.0.2-HrqZFRpCUr5kkKpBas09N
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2017 by Peter Simons
maintainer:           Peter Simons <simons@cryp.to>
author:               Peter Simons, John Lato, Jonathan Childress
homepage:             http://github.com/peti/hsyslog
synopsis:             FFI interface to syslog(3) from POSIX.1-2001
description:
    A Haskell interface to @syslog(3)@ as specified in
    <http://pubs.opengroup.org/onlinepubs/9699919799/functions/syslog.html POSIX.1-2008>.
    The entire public API lives in "System.Posix.Syslog". There is a set of exposed
    modules available underneath that one, which contain various implementation details
    that may be useful to other developers who want to implement syslog-related
    functionality. /Users/ of @syslog@, however, do not need them.

    An example program that demonstrates how to use this library is available in the
    <https://github.com/peti/hsyslog/blob/master/example/Main.hs examples> directory of
    this package.

category:             Foreign
abi:                  e015bcbcf650b7f25516a8513af2a8a9
exposed:              True
exposed-modules:
    System.Posix.Syslog System.Posix.Syslog.Facility
    System.Posix.Syslog.Functions System.Posix.Syslog.LogMask
    System.Posix.Syslog.Options System.Posix.Syslog.Priority

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hsyslog-5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hsyslog-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyslog
hs-libraries:         HShsyslog-5.0.2-HrqZFRpCUr5kkKpBas09N
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-hsyslog/html/hsyslog.haddock
haddock-html:         /usr/share/doc/haskell-hsyslog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyslog-5.0.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyslog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hsyslog
version:              5.0.2
visibility:           public
id:                   hsyslog-5.0.2-XL7N6hDn4cLfQ4jPw13rI
key:                  hsyslog-5.0.2-XL7N6hDn4cLfQ4jPw13rI
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2017 by Peter Simons
maintainer:           Peter Simons <simons@cryp.to>
author:               Peter Simons, John Lato, Jonathan Childress
homepage:             http://github.com/peti/hsyslog
synopsis:             FFI interface to syslog(3) from POSIX.1-2001
description:
    A Haskell interface to @syslog(3)@ as specified in
    <http://pubs.opengroup.org/onlinepubs/9699919799/functions/syslog.html POSIX.1-2008>.
    The entire public API lives in "System.Posix.Syslog". There is a set of exposed
    modules available underneath that one, which contain various implementation details
    that may be useful to other developers who want to implement syslog-related
    functionality. /Users/ of @syslog@, however, do not need them.

    An example program that demonstrates how to use this library is available in the
    <https://github.com/peti/hsyslog/blob/master/example/Main.hs examples> directory of
    this package.

category:             Foreign
abi:                  fff7f585cc5a1b516f5107af64bf4f97
exposed:              True
exposed-modules:
    System.Posix.Syslog System.Posix.Syslog.Facility
    System.Posix.Syslog.Functions System.Posix.Syslog.LogMask
    System.Posix.Syslog.Options System.Posix.Syslog.Priority

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hsyslog-5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hsyslog-5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hsyslog-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyslog
hs-libraries:         HShsyslog-5.0.2-XL7N6hDn4cLfQ4jPw13rI
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-hsyslog/html/hsyslog.haddock
haddock-html:         /usr/share/doc/haskell-hsyslog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
